@@ -26,7 +26,7 @@
 #include <glib/gprintf.h>
 #include <glib.h>
 
-#include "../drivers/mysocials_driver.h"
+#include <libvkontakte0/mysocials_driver.h>
 
 #include "ui_general.h"
 #include "ui_strings.h"
